"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _browserDetection = require("./browser-detection");

var _promiseTimeout = require("./promise-timeout");

var _uidCookieValue = require("./uid-cookie-value");

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const encode = obj => {
  const str = JSON.stringify(obj);
  return btoa(encodeURIComponent(str).replace(/%([0-9A-F]{2})/g, (_, p1) => String.fromCharCode('0x' + p1)));
}; // does the fetch, but swallows errors, and
// resolves promise after a max of 250 ms not matter what


const doFetch = (url, obj, debug = false) => {
  let builtUrl = url + '?data=' + encode(obj);

  if (debug) {
    builtUrl += '&verbose=1';
  }

  const promise = fetch(builtUrl).then(res => debug ? res.json() : res.text()).then(res => {
    if (!debug && res !== '1') {
      console.error('mixpanel request failed');
    } else {
      console.info(res);
    }
  }).catch(() => {
    console.error('mixpanel request failed');
  });
  return (0, _promiseTimeout.promiseTimeout)({
    promise,
    timeout: 250,
    shouldReject: false
  });
};

var _default = (token, debug) => {
  const envProps = (0, _browserDetection.getEnvironmentData)();
  const anonId = (0, _uidCookieValue.getOrCreateUid)();
  let realId;

  const trackApi = (event, props = {}) => doFetch('https://api.mixpanel.com/track/', {
    event,
    properties: _objectSpread({
      token,
      distinct_id: realId || anonId,
      $current_url: window.location.href,
      $screen_height: window.innerHeight,
      $screen_width: window.innerWidth,
      $browser: envProps.browser,
      $browser_version: envProps.browserVersion,
      $os: envProps.os,
      $device: envProps.device,
      nativeAppVersion: envProps.nativeAppVersion,
      app_version: window.version || 0
    }, props)
  }, debug);

  return {
    identify: (_ref) => {
      let {
        id,
        name,
        email
      } = _ref,
          rest = _objectWithoutProperties(_ref, ["id", "name", "email"]);

      const props = _objectSpread({
        $anon_id: anonId
      }, rest);

      if (id) {
        realId = id;
        props.$identified_id = id;
        props.$name = name;
        props.$email = email;
      }

      return trackApi('$identify', props);
    },
    track: trackApi
  };
};

exports.default = _default;